# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/anonstore.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/anonstore.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=b'\n#zsearch_definitions/anonstore.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\"\xb2\x01\n\x0e\x43TServerStatus\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x14\n\x0c\x63t_timestamp\x18\x02 \x01(\x03\x12\x16\n\x0epull_timestamp\x18\x03 \x01(\x03\x12\x16\n\x0epush_timestamp\x18\x04 \x01(\x03\x12*\n\x0bpush_status\x18\x05 \x01(\x0e\x32\x15.zsearch.CTPushStatus\x12\x0b\n\x03sct\x18\x06 \x01(\x0c\x12\x12\n\npush_error\x18\x07 \x01(\t\"\x99\n\n\x08\x43TStatus\x12+\n\ncensys_dev\x18\x01 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\'\n\x06\x63\x65nsys\x18\x02 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0egoogle_aviator\x18\n \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0cgoogle_pilot\x18\x0b \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10google_rocketeer\x18\x0c \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x32\n\x11google_submariner\x18\r \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_testtube\x18\x0e \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rgoogle_icarus\x18\x0f \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_skydiver\x18\x10 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_daedalus\x18\x11 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x64igicert_ct1\x18\x14 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rizenpe_com_ct\x18\x15 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rizenpe_eus_ct\x18\x16 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0esymantec_ws_ct\x18\x17 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10symantec_ws_vega\x18\x18 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0cwosign_ctlog\x18\x19 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12*\n\twosign_ct\x18\x1a \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0e\x63nnic_ctserver\x18\x1b \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12(\n\x07gdca_ct\x18\x1c \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12,\n\x0bstartssl_ct\x18\x1d \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12+\n\ncertly_log\x18\x1e \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10venafi_api_ctlog\x18\x1f \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x32\n\x11symantec_ws_deneb\x18  \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x33\n\x12nordu_ct_plausible\x18! \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12,\n\x0b\x63omodo_dodo\x18\" \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0e\x63omodo_mammoth\x18# \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12+\n\ngdca_ctlog\x18$ \x01(\x0b\x32\x17.zsearch.CTServerStatus\"\xa0\x01\n\x0fRootStoreStatus\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x11\n\twas_valid\x18\x02 \x01(\x08\x12\x14\n\x0ctrusted_path\x18\x03 \x01(\x08\x12\x18\n\x10was_trusted_path\x18\x04 \x01(\x08\x12&\n\x04type\x18\x05 \x01(\x0e\x32\x18.zsearch.CertificateType\x12\x13\n\x0b\x62lacklisted\x18\x06 \x01(\x08\"\x8a\x03\n\x15\x43\x65rtificateValidation\x12%\n\x03nss\x18\x04 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12+\n\tmicrosoft\x18\x05 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\'\n\x05\x61pple\x18\x06 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12&\n\x04java\x18\x07 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12)\n\x07\x61ndroid\x18\x08 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\x33\n\x11google_ct_primary\x18\t \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\x34\n\x12google_ct_testtube\x18\n \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\x36\n\x14google_ct_submariner\x18\x0b \x01(\x0b\x32\x18.zsearch.RootStoreStatus\"\xba\x02\n\x17MozillaSalesForceStatus\x12\x12\n\ncurrent_in\x18\x01 \x01(\x08\x12\x0e\n\x06was_in\x18\x02 \x01(\x08\x12\x12\n\nowner_name\x18\x03 \x01(\t\x12\x13\n\x0bparent_name\x18\x04 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x05 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_policy\x18\x06 \x01(\t\x12(\n certification_practice_statement\x18\x07 \x01(\t\x12\x19\n\x11\x63p_same_as_parent\x18\x08 \x01(\x08\x12\x1c\n\x14\x61udit_same_as_parent\x18\t \x01(\x08\x12\x16\n\x0estandard_audit\x18\n \x01(\t\x12\x10\n\x08\x62r_audit\x18\x0b \x01(\t\x12\x0f\n\x07\x61uditor\x18\x0c \x01(\t\"\xca\x07\n\x0b\x43\x65rtificate\x12\x0e\n\x06sha1fp\x18\x01 \x01(\x0c\x12\x10\n\x08sha256fp\x18\x02 \x01(\x0c\x12\x0b\n\x03raw\x18\x03 \x01(\x0c\x12\x0e\n\x06parsed\x18\x04 \x01(\t\x12\x0f\n\x07parents\x18\x05 \x03(\x0c\x12\x12\n\x06in_nss\x18\x06 \x01(\x08\x42\x02\x18\x01\x12\x18\n\x0cin_microsoft\x18\x07 \x01(\x08\x42\x02\x18\x01\x12\x14\n\x08in_apple\x18\x08 \x01(\x08\x42\x02\x18\x01\x12 \n\x14validation_timestamp\x18\n \x01(\rB\x02\x18\x01\x12\x15\n\tvalid_nss\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0fvalid_microsoft\x18\x0c \x01(\x08\x42\x02\x18\x01\x12\x17\n\x0bvalid_apple\x18\r \x01(\x08\x42\x02\x18\x01\x12\x19\n\rwas_valid_nss\x18\x0e \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13was_valid_microsoft\x18\x0f \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0fwas_valid_apple\x18\x10 \x01(\x08\x42\x02\x18\x01\x12\x16\n\nwas_in_nss\x18\x11 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10was_in_microsoft\x18\x12 \x01(\x08\x42\x02\x18\x01\x12\x18\n\x0cwas_in_apple\x18\x13 \x01(\x08\x42\x02\x18\x01\x12\x1d\n\x11\x63urrent_valid_nss\x18\x14 \x01(\x08\x42\x02\x18\x01\x12#\n\x17\x63urrent_valid_microsoft\x18\x15 \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13\x63urrent_valid_apple\x18\x16 \x01(\x08\x42\x02\x18\x01\x12\x1a\n\x0e\x63urrent_in_nss\x18\x17 \x01(\x08\x42\x02\x18\x01\x12 \n\x14\x63urrent_in_microsoft\x18\x18 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10\x63urrent_in_apple\x18\x19 \x01(\x08\x42\x02\x18\x01\x12\x16\n\x0epost_processed\x18\x1a \x01(\x08\x12\x1b\n\x13should_post_process\x18\x1b \x01(\x08\x12\x1b\n\x13\x64o_not_post_process\x18$ \x01(\x08\x12\x1e\n\x16post_process_timestamp\x18% \x01(\r\x12*\n\x06source\x18\x1c \x01(\x0e\x32\x1a.zsearch.CertificateSource\x12\x14\n\x0cseen_in_scan\x18\x1d \x01(\x08\x12\x1d\n\x02\x63t\x18\x1e \x01(\x0b\x32\x11.zsearch.CTStatus\x12\x33\n\tnss_audit\x18\x1f \x01(\x0b\x32 .zsearch.MozillaSalesForceStatus\x12\x12\n\nis_precert\x18  \x01(\x08\x12\x32\n\nvalidation\x18# \x01(\x0b\x32\x1e.zsearch.CertificateValidation\"N\n\x13RSACryptographicKey\x12\x0f\n\x07modulus\x18\x01 \x01(\x0c\x12\x10\n\x08\x65xponent\x18\x02 \x01(\x0c\x12\t\n\x01p\x18\x03 \x01(\x0c\x12\t\n\x01q\x18\x04 \x01(\x0c\"L\n\x13\x44SACryptographicKey\x12\t\n\x01p\x18\x01 \x01(\x0c\x12\t\n\x01q\x18\x02 \x01(\x0c\x12\t\n\x01g\x18\x03 \x01(\x0c\x12\t\n\x01y\x18\x04 \x01(\x0c\x12\t\n\x01x\x18\x05 \x01(\x0c\"K\n\x13\x45\x43\x43\x43ryptographicKey\x12\r\n\x05\x63urve\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x0c\x12\t\n\x01y\x18\x03 \x01(\x0c\x12\x0f\n\x07private\x18\x04 \x01(\x0c\"\xc8\x02\n\x10\x43ryptographicKey\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.zsearch.CryptographicKey.KeyType\x12+\n\x03rsa\x18\x02 \x01(\x0b\x32\x1c.zsearch.RSACryptographicKeyH\x00\x12+\n\x03\x64sa\x18\x03 \x01(\x0b\x32\x1c.zsearch.DSACryptographicKeyH\x00\x12+\n\x03\x65\x63\x63\x18\x04 \x01(\x0b\x32\x1c.zsearch.ECCCryptographicKeyH\x00\x12\x0e\n\x06\x62roken\x18\x05 \x01(\x08\x12\x0e\n\x06\x63ommon\x18\x06 \x01(\x08\x12\x0e\n\x06\x64\x65\x62ian\x18\x07 \x01(\x08\"?\n\x07KeyType\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x07\n\x03RSA\x10\x02\x12\x07\n\x03\x44SA\x10\x03\x12\x07\n\x03\x45\x43\x43\x10\x04\x42\x0b\n\tkey_oneof\"\x88\x03\n\x0f\x41nonymousRecord\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x10\x12\x0f\n\x07scan_id\x18\x03 \x01(\r\x12\x14\n\x08\x65xported\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\'\n\x08userdata\x18\x05 \x01(\x0b\x32\x15.zsearch.UserdataAtom\x12\x0e\n\x04\x64\x61ta\x18\x06 \x01(\tH\x00\x12\x12\n\x08raw_data\x18\x07 \x01(\x0cH\x00\x12+\n\x0b\x63\x65rtificate\x18\x08 \x01(\x0b\x32\x14.zsearch.CertificateH\x00\x12(\n\x03key\x18\t \x01(\x0b\x32\x19.zsearch.CryptographicKeyH\x00\x12\x1d\n\x02\x61s\x18\n \x01(\x0b\x32\x0f.zsearch.ASAtomH\x00\x12$\n\x08metadata\x18\x0e \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\x07\x12\x10\n\x08\x61\x64\x64\x65\x64_at\x18\x11 \x01(\x07\x42\x0c\n\noneof_data\"\x8e\x02\n\x13\x45xternalCertificate\x12*\n\x06source\x18\x01 \x01(\x0e\x32\x1a.zsearch.CertificateSource\x12\x32\n\x10\x61nonymous_record\x18\x02 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\x12$\n\tct_server\x18\x03 \x01(\x0e\x32\x11.zsearch.CTServer\x12*\n\tct_status\x18\x04 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x34\n\nnss_status\x18\x05 \x01(\x0b\x32 .zsearch.MozillaSalesForceStatus\x12\x0f\n\x07tbsHash\x18\x06 \x01(\x0c\"c\n\x03SCT\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12!\n\x06server\x18\x02 \x01(\x0e\x32\x11.zsearch.CTServer\x12\'\n\x06status\x18\x03 \x01(\x0b\x32\x17.zsearch.CTServerStatus\"\xbe\x02\n\x0e\x41nonymousDelta\x12\x35\n\ndelta_type\x18\x01 \x01(\x0e\x32!.zsearch.AnonymousDelta.DeltaType\x12\x37\n\x0b\x64\x65lta_scope\x18\x02 \x01(\x0e\x32\".zsearch.AnonymousDelta.DeltaScope\x12(\n\x06record\x18\x03 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\":\n\tDeltaType\x12\x0f\n\x0b\x44T_RESERVED\x10\x00\x12\r\n\tDT_UPDATE\x10\x01\x12\r\n\tDT_DELETE\x10\x02\"V\n\nDeltaScope\x12\x12\n\x0eSCOPE_RESERVED\x10\x00\x12\x13\n\x0fSCOPE_NO_CHANGE\x10\x01\x12\r\n\tSCOPE_NEW\x10\x02\x12\x10\n\x0cSCOPE_UPDATE\x10\x03*\xeb\x01\n\x0c\x43TPushStatus\x12\x1b\n\x17\x43T_PUSH_STATUS_RESERVED\x10\x00\x12\x1a\n\x16\x43T_PUSH_STATUS_UNKNOWN\x10\x01\x12\x1a\n\x16\x43T_PUSH_STATUS_SUCCESS\x10\x02\x12 \n\x1c\x43T_PUSH_STATUS_UNKNOWN_ERROR\x10\x03\x12\x1f\n\x1b\x43T_PUSH_STATUS_INVALID_ROOT\x10\x04\x12!\n\x1d\x43T_PUSH_STATUS_ALREADY_EXISTS\x10\x05\x12 \n\x1c\x43T_PUSH_STATUS_WILL_NOT_PUSH\x10\x06*\xa7\x01\n\x0f\x43\x65rtificateType\x12\x1d\n\x19\x43\x45RTIFICATE_TYPE_RESERVED\x10\x00\x12\x1c\n\x18\x43\x45RTIFICATE_TYPE_UNKNOWN\x10\x01\x12\x19\n\x15\x43\x45RTIFICATE_TYPE_LEAF\x10\x02\x12!\n\x1d\x43\x45RTIFICATE_TYPE_INTERMEDIATE\x10\x03\x12\x19\n\x15\x43\x45RTIFICATE_TYPE_ROOT\x10\x04*\xb7\x02\n\x11\x43\x65rtificateSource\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_RESERVED\x10\x00\x12\x1e\n\x1a\x43\x45RTIFICATE_SOURCE_UNKNOWN\x10\x01\x12\x1b\n\x17\x43\x45RTIFICATE_SOURCE_SCAN\x10\x02\x12\x19\n\x15\x43\x45RTIFICATE_SOURCE_CT\x10\x03\x12)\n%CERTIFICATE_SOURCE_MOZILLA_SALESFORCE\x10\x04\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_RESEARCH\x10\x05\x12\x1d\n\x19\x43\x45RTIFICATE_SOURCE_RAPID7\x10\x06\x12\x1d\n\x19\x43\x45RTIFICATE_SOURCE_HUBBLE\x10\x07\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_CT_CHAIN\x10\x08*\xc3\x06\n\x08\x43TServer\x12\x16\n\x12\x43T_SERVER_RESERVED\x10\x00\x12\x1f\n\x1b\x43T_SERVER_CENSYS_PRODUCTION\x10\x01\x12 \n\x1c\x43T_SERVER_CENSYS_DEVELOPMENT\x10\x02\x12\x1c\n\x18\x43T_SERVER_GOOGLE_AVIATOR\x10\n\x12\x1a\n\x16\x43T_SERVER_GOOGLE_PILOT\x10\x0b\x12\x1e\n\x1a\x43T_SERVER_GOOGLE_ROCKETEER\x10\x0c\x12\x1f\n\x1b\x43T_SERVER_GOOGLE_SUBMARINER\x10\r\x12\x1d\n\x19\x43T_SERVER_GOOGLE_TESTTUBE\x10\x0e\x12\x1b\n\x17\x43T_SERVER_GOOGLE_ICARUS\x10\x0f\x12\x1d\n\x19\x43T_SERVER_GOOGLE_SKYDIVER\x10\x10\x12\x1d\n\x19\x43T_SERVER_GOOGLE_DAEDALUS\x10\x11\x12\x1a\n\x16\x43T_SERVER_DIGICERT_CT1\x10\x14\x12\x1b\n\x17\x43T_SERVER_IZENPE_COM_CT\x10\x15\x12\x1b\n\x17\x43T_SERVER_IZENPE_EUS_CT\x10\x16\x12\x1c\n\x18\x43T_SERVER_SYMANTEC_WS_CT\x10\x17\x12\x1e\n\x1a\x43T_SERVER_SYMANTEC_WS_VEGA\x10\x18\x12\x1a\n\x16\x43T_SERVER_WOSIGN_CTLOG\x10\x19\x12\x17\n\x13\x43T_SERVER_WOSIGN_CT\x10\x1a\x12\x1c\n\x18\x43T_SERVER_CNNIC_CTSERVER\x10\x1b\x12\x15\n\x11\x43T_SERVER_GDCA_CT\x10\x1c\x12\x19\n\x15\x43T_SERVER_STARTSSL_CT\x10\x1d\x12\x18\n\x14\x43T_SERVER_CERTLY_LOG\x10\x1e\x12\x1e\n\x1a\x43T_SERVER_VENAFI_API_CTLOG\x10\x1f\x12\x1f\n\x1b\x43T_SERVER_SYMANTEC_WS_DENEB\x10 \x12 \n\x1c\x43T_SERVER_NORDU_CT_PLAUSIBLE\x10!\x12\x18\n\x14\x43T_SERVER_GDCA_CTLOG\x10\"\x12\x19\n\x15\x43T_SERVER_COMODO_DODO\x10#\x12\x1c\n\x18\x43T_SERVER_COMODO_MAMMOTH\x10$b\x06proto3'
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CTPUSHSTATUS = _descriptor.EnumDescriptor(
  name='CTPushStatus',
  full_name='zsearch.CTPushStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_SUCCESS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_UNKNOWN_ERROR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_INVALID_ROOT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_ALREADY_EXISTS', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_WILL_NOT_PUSH', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5078,
  serialized_end=5313,
)
_sym_db.RegisterEnumDescriptor(_CTPUSHSTATUS)

CTPushStatus = enum_type_wrapper.EnumTypeWrapper(_CTPUSHSTATUS)
_CERTIFICATETYPE = _descriptor.EnumDescriptor(
  name='CertificateType',
  full_name='zsearch.CertificateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_LEAF', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_INTERMEDIATE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_ROOT', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5316,
  serialized_end=5483,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATETYPE)

CertificateType = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATETYPE)
_CERTIFICATESOURCE = _descriptor.EnumDescriptor(
  name='CertificateSource',
  full_name='zsearch.CertificateSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_SCAN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_CT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_MOZILLA_SALESFORCE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RESEARCH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RAPID7', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_HUBBLE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_CT_CHAIN', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5486,
  serialized_end=5797,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESOURCE)

CertificateSource = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATESOURCE)
_CTSERVER = _descriptor.EnumDescriptor(
  name='CTServer',
  full_name='zsearch.CTServer',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CENSYS_PRODUCTION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CENSYS_DEVELOPMENT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_AVIATOR', index=3, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_PILOT', index=4, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_ROCKETEER', index=5, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_SUBMARINER', index=6, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_TESTTUBE', index=7, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_ICARUS', index=8, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_SKYDIVER', index=9, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_DAEDALUS', index=10, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_DIGICERT_CT1', index=11, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_IZENPE_COM_CT', index=12, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_IZENPE_EUS_CT', index=13, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_CT', index=14, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_VEGA', index=15, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_WOSIGN_CTLOG', index=16, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_WOSIGN_CT', index=17, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CNNIC_CTSERVER', index=18, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GDCA_CT', index=19, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_STARTSSL_CT', index=20, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CERTLY_LOG', index=21, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_VENAFI_API_CTLOG', index=22, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_DENEB', index=23, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_NORDU_CT_PLAUSIBLE', index=24, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GDCA_CTLOG', index=25, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_DODO', index=26, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_MAMMOTH', index=27, number=36,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5800,
  serialized_end=6635,
)
_sym_db.RegisterEnumDescriptor(_CTSERVER)

CTServer = enum_type_wrapper.EnumTypeWrapper(_CTSERVER)
CT_PUSH_STATUS_RESERVED = 0
CT_PUSH_STATUS_UNKNOWN = 1
CT_PUSH_STATUS_SUCCESS = 2
CT_PUSH_STATUS_UNKNOWN_ERROR = 3
CT_PUSH_STATUS_INVALID_ROOT = 4
CT_PUSH_STATUS_ALREADY_EXISTS = 5
CT_PUSH_STATUS_WILL_NOT_PUSH = 6
CERTIFICATE_TYPE_RESERVED = 0
CERTIFICATE_TYPE_UNKNOWN = 1
CERTIFICATE_TYPE_LEAF = 2
CERTIFICATE_TYPE_INTERMEDIATE = 3
CERTIFICATE_TYPE_ROOT = 4
CERTIFICATE_SOURCE_RESERVED = 0
CERTIFICATE_SOURCE_UNKNOWN = 1
CERTIFICATE_SOURCE_SCAN = 2
CERTIFICATE_SOURCE_CT = 3
CERTIFICATE_SOURCE_MOZILLA_SALESFORCE = 4
CERTIFICATE_SOURCE_RESEARCH = 5
CERTIFICATE_SOURCE_RAPID7 = 6
CERTIFICATE_SOURCE_HUBBLE = 7
CERTIFICATE_SOURCE_CT_CHAIN = 8
CT_SERVER_RESERVED = 0
CT_SERVER_CENSYS_PRODUCTION = 1
CT_SERVER_CENSYS_DEVELOPMENT = 2
CT_SERVER_GOOGLE_AVIATOR = 10
CT_SERVER_GOOGLE_PILOT = 11
CT_SERVER_GOOGLE_ROCKETEER = 12
CT_SERVER_GOOGLE_SUBMARINER = 13
CT_SERVER_GOOGLE_TESTTUBE = 14
CT_SERVER_GOOGLE_ICARUS = 15
CT_SERVER_GOOGLE_SKYDIVER = 16
CT_SERVER_GOOGLE_DAEDALUS = 17
CT_SERVER_DIGICERT_CT1 = 20
CT_SERVER_IZENPE_COM_CT = 21
CT_SERVER_IZENPE_EUS_CT = 22
CT_SERVER_SYMANTEC_WS_CT = 23
CT_SERVER_SYMANTEC_WS_VEGA = 24
CT_SERVER_WOSIGN_CTLOG = 25
CT_SERVER_WOSIGN_CT = 26
CT_SERVER_CNNIC_CTSERVER = 27
CT_SERVER_GDCA_CT = 28
CT_SERVER_STARTSSL_CT = 29
CT_SERVER_CERTLY_LOG = 30
CT_SERVER_VENAFI_API_CTLOG = 31
CT_SERVER_SYMANTEC_WS_DENEB = 32
CT_SERVER_NORDU_CT_PLAUSIBLE = 33
CT_SERVER_GDCA_CTLOG = 34
CT_SERVER_COMODO_DODO = 35
CT_SERVER_COMODO_MAMMOTH = 36


_CRYPTOGRAPHICKEY_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='zsearch.CryptographicKey.KeyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RSA', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DSA', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ECC', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3909,
  serialized_end=3972,
)
_sym_db.RegisterEnumDescriptor(_CRYPTOGRAPHICKEY_KEYTYPE)

_ANONYMOUSDELTA_DELTATYPE = _descriptor.EnumDescriptor(
  name='DeltaType',
  full_name='zsearch.AnonymousDelta.DeltaType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DT_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_UPDATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_DELETE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4929,
  serialized_end=4987,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTATYPE)

_ANONYMOUSDELTA_DELTASCOPE = _descriptor.EnumDescriptor(
  name='DeltaScope',
  full_name='zsearch.AnonymousDelta.DeltaScope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCOPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NO_CHANGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NEW', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_UPDATE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4989,
  serialized_end=5075,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTASCOPE)


_CTSERVERSTATUS = _descriptor.Descriptor(
  name='CTServerStatus',
  full_name='zsearch.CTServerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='zsearch.CTServerStatus.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_timestamp', full_name='zsearch.CTServerStatus.ct_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pull_timestamp', full_name='zsearch.CTServerStatus.pull_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_timestamp', full_name='zsearch.CTServerStatus.push_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_status', full_name='zsearch.CTServerStatus.push_status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sct', full_name='zsearch.CTServerStatus.sct', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_error', full_name='zsearch.CTServerStatus.push_error', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=261,
)


_CTSTATUS = _descriptor.Descriptor(
  name='CTStatus',
  full_name='zsearch.CTStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='censys_dev', full_name='zsearch.CTStatus.censys_dev', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='censys', full_name='zsearch.CTStatus.censys', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_aviator', full_name='zsearch.CTStatus.google_aviator', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_pilot', full_name='zsearch.CTStatus.google_pilot', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_rocketeer', full_name='zsearch.CTStatus.google_rocketeer', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_submariner', full_name='zsearch.CTStatus.google_submariner', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_testtube', full_name='zsearch.CTStatus.google_testtube', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_icarus', full_name='zsearch.CTStatus.google_icarus', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_skydiver', full_name='zsearch.CTStatus.google_skydiver', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_daedalus', full_name='zsearch.CTStatus.google_daedalus', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='digicert_ct1', full_name='zsearch.CTStatus.digicert_ct1', index=10,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='izenpe_com_ct', full_name='zsearch.CTStatus.izenpe_com_ct', index=11,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='izenpe_eus_ct', full_name='zsearch.CTStatus.izenpe_eus_ct', index=12,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_ct', full_name='zsearch.CTStatus.symantec_ws_ct', index=13,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_vega', full_name='zsearch.CTStatus.symantec_ws_vega', index=14,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wosign_ctlog', full_name='zsearch.CTStatus.wosign_ctlog', index=15,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wosign_ct', full_name='zsearch.CTStatus.wosign_ct', index=16,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cnnic_ctserver', full_name='zsearch.CTStatus.cnnic_ctserver', index=17,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gdca_ct', full_name='zsearch.CTStatus.gdca_ct', index=18,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startssl_ct', full_name='zsearch.CTStatus.startssl_ct', index=19,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certly_log', full_name='zsearch.CTStatus.certly_log', index=20,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='venafi_api_ctlog', full_name='zsearch.CTStatus.venafi_api_ctlog', index=21,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_deneb', full_name='zsearch.CTStatus.symantec_ws_deneb', index=22,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nordu_ct_plausible', full_name='zsearch.CTStatus.nordu_ct_plausible', index=23,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_dodo', full_name='zsearch.CTStatus.comodo_dodo', index=24,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_mammoth', full_name='zsearch.CTStatus.comodo_mammoth', index=25,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gdca_ctlog', full_name='zsearch.CTStatus.gdca_ctlog', index=26,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=1569,
)


_ROOTSTORESTATUS = _descriptor.Descriptor(
  name='RootStoreStatus',
  full_name='zsearch.RootStoreStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='zsearch.RootStoreStatus.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_valid', full_name='zsearch.RootStoreStatus.was_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trusted_path', full_name='zsearch.RootStoreStatus.trusted_path', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_trusted_path', full_name='zsearch.RootStoreStatus.was_trusted_path', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.RootStoreStatus.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blacklisted', full_name='zsearch.RootStoreStatus.blacklisted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1572,
  serialized_end=1732,
)


_CERTIFICATEVALIDATION = _descriptor.Descriptor(
  name='CertificateValidation',
  full_name='zsearch.CertificateValidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nss', full_name='zsearch.CertificateValidation.nss', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='microsoft', full_name='zsearch.CertificateValidation.microsoft', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apple', full_name='zsearch.CertificateValidation.apple', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='java', full_name='zsearch.CertificateValidation.java', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='android', full_name='zsearch.CertificateValidation.android', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_ct_primary', full_name='zsearch.CertificateValidation.google_ct_primary', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_ct_testtube', full_name='zsearch.CertificateValidation.google_ct_testtube', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_ct_submariner', full_name='zsearch.CertificateValidation.google_ct_submariner', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1735,
  serialized_end=2129,
)


_MOZILLASALESFORCESTATUS = _descriptor.Descriptor(
  name='MozillaSalesForceStatus',
  full_name='zsearch.MozillaSalesForceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_in', full_name='zsearch.MozillaSalesForceStatus.current_in', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_in', full_name='zsearch.MozillaSalesForceStatus.was_in', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_name', full_name='zsearch.MozillaSalesForceStatus.owner_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_name', full_name='zsearch.MozillaSalesForceStatus.parent_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate_name', full_name='zsearch.MozillaSalesForceStatus.certificate_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate_policy', full_name='zsearch.MozillaSalesForceStatus.certificate_policy', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certification_practice_statement', full_name='zsearch.MozillaSalesForceStatus.certification_practice_statement', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cp_same_as_parent', full_name='zsearch.MozillaSalesForceStatus.cp_same_as_parent', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_same_as_parent', full_name='zsearch.MozillaSalesForceStatus.audit_same_as_parent', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='standard_audit', full_name='zsearch.MozillaSalesForceStatus.standard_audit', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='br_audit', full_name='zsearch.MozillaSalesForceStatus.br_audit', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auditor', full_name='zsearch.MozillaSalesForceStatus.auditor', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2446,
)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='zsearch.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha1fp', full_name='zsearch.Certificate.sha1fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Certificate.sha256fp', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw', full_name='zsearch.Certificate.raw', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='zsearch.Certificate.parsed', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='zsearch.Certificate.parents', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_nss', full_name='zsearch.Certificate.in_nss', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='in_microsoft', full_name='zsearch.Certificate.in_microsoft', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='in_apple', full_name='zsearch.Certificate.in_apple', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='validation_timestamp', full_name='zsearch.Certificate.validation_timestamp', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='valid_nss', full_name='zsearch.Certificate.valid_nss', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='valid_microsoft', full_name='zsearch.Certificate.valid_microsoft', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='valid_apple', full_name='zsearch.Certificate.valid_apple', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='was_valid_nss', full_name='zsearch.Certificate.was_valid_nss', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='was_valid_microsoft', full_name='zsearch.Certificate.was_valid_microsoft', index=13,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='was_valid_apple', full_name='zsearch.Certificate.was_valid_apple', index=14,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='was_in_nss', full_name='zsearch.Certificate.was_in_nss', index=15,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='was_in_microsoft', full_name='zsearch.Certificate.was_in_microsoft', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='was_in_apple', full_name='zsearch.Certificate.was_in_apple', index=17,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='current_valid_nss', full_name='zsearch.Certificate.current_valid_nss', index=18,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='current_valid_microsoft', full_name='zsearch.Certificate.current_valid_microsoft', index=19,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='current_valid_apple', full_name='zsearch.Certificate.current_valid_apple', index=20,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='current_in_nss', full_name='zsearch.Certificate.current_in_nss', index=21,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='current_in_microsoft', full_name='zsearch.Certificate.current_in_microsoft', index=22,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='current_in_apple', full_name='zsearch.Certificate.current_in_apple', index=23,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='post_processed', full_name='zsearch.Certificate.post_processed', index=24,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='should_post_process', full_name='zsearch.Certificate.should_post_process', index=25,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_not_post_process', full_name='zsearch.Certificate.do_not_post_process', index=26,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_process_timestamp', full_name='zsearch.Certificate.post_process_timestamp', index=27,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='zsearch.Certificate.source', index=28,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seen_in_scan', full_name='zsearch.Certificate.seen_in_scan', index=29,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct', full_name='zsearch.Certificate.ct', index=30,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nss_audit', full_name='zsearch.Certificate.nss_audit', index=31,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_precert', full_name='zsearch.Certificate.is_precert', index=32,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='validation', full_name='zsearch.Certificate.validation', index=33,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2449,
  serialized_end=3419,
)


_RSACRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='RSACryptographicKey',
  full_name='zsearch.RSACryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulus', full_name='zsearch.RSACryptographicKey.modulus', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exponent', full_name='zsearch.RSACryptographicKey.exponent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='p', full_name='zsearch.RSACryptographicKey.p', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='q', full_name='zsearch.RSACryptographicKey.q', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3421,
  serialized_end=3499,
)


_DSACRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='DSACryptographicKey',
  full_name='zsearch.DSACryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='zsearch.DSACryptographicKey.p', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='q', full_name='zsearch.DSACryptographicKey.q', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g', full_name='zsearch.DSACryptographicKey.g', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='zsearch.DSACryptographicKey.y', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='zsearch.DSACryptographicKey.x', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3501,
  serialized_end=3577,
)


_ECCCRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='ECCCryptographicKey',
  full_name='zsearch.ECCCryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='curve', full_name='zsearch.ECCCryptographicKey.curve', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='zsearch.ECCCryptographicKey.x', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='zsearch.ECCCryptographicKey.y', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private', full_name='zsearch.ECCCryptographicKey.private', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3579,
  serialized_end=3654,
)


_CRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='CryptographicKey',
  full_name='zsearch.CryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.CryptographicKey.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rsa', full_name='zsearch.CryptographicKey.rsa', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dsa', full_name='zsearch.CryptographicKey.dsa', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ecc', full_name='zsearch.CryptographicKey.ecc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broken', full_name='zsearch.CryptographicKey.broken', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='zsearch.CryptographicKey.common', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debian', full_name='zsearch.CryptographicKey.debian', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRYPTOGRAPHICKEY_KEYTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key_oneof', full_name='zsearch.CryptographicKey.key_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3657,
  serialized_end=3985,
)


_ANONYMOUSRECORD = _descriptor.Descriptor(
  name='AnonymousRecord',
  full_name='zsearch.AnonymousRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousRecord.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.AnonymousRecord.timestamp', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_id', full_name='zsearch.AnonymousRecord.scan_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exported', full_name='zsearch.AnonymousRecord.exported', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.AnonymousRecord.userdata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.AnonymousRecord.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_data', full_name='zsearch.AnonymousRecord.raw_data', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='zsearch.AnonymousRecord.certificate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.AnonymousRecord.key', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as', full_name='zsearch.AnonymousRecord.as', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.AnonymousRecord.metadata', index=10,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.AnonymousRecord.tags', index=11,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='zsearch.AnonymousRecord.updated_at', index=12,
      number=16, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='added_at', full_name='zsearch.AnonymousRecord.added_at', index=13,
      number=17, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_data', full_name='zsearch.AnonymousRecord.oneof_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3988,
  serialized_end=4380,
)


_EXTERNALCERTIFICATE = _descriptor.Descriptor(
  name='ExternalCertificate',
  full_name='zsearch.ExternalCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='zsearch.ExternalCertificate.source', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='anonymous_record', full_name='zsearch.ExternalCertificate.anonymous_record', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_server', full_name='zsearch.ExternalCertificate.ct_server', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_status', full_name='zsearch.ExternalCertificate.ct_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nss_status', full_name='zsearch.ExternalCertificate.nss_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tbsHash', full_name='zsearch.ExternalCertificate.tbsHash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4383,
  serialized_end=4653,
)


_SCT = _descriptor.Descriptor(
  name='SCT',
  full_name='zsearch.SCT',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.SCT.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server', full_name='zsearch.SCT.server', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.SCT.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4655,
  serialized_end=4754,
)


_ANONYMOUSDELTA = _descriptor.Descriptor(
  name='AnonymousDelta',
  full_name='zsearch.AnonymousDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta_type', full_name='zsearch.AnonymousDelta.delta_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_scope', full_name='zsearch.AnonymousDelta.delta_scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.AnonymousDelta.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANONYMOUSDELTA_DELTATYPE,
    _ANONYMOUSDELTA_DELTASCOPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4757,
  serialized_end=5075,
)

_CTSERVERSTATUS.fields_by_name['push_status'].enum_type = _CTPUSHSTATUS
_CTSTATUS.fields_by_name['censys_dev'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['censys'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_aviator'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_pilot'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_rocketeer'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_submariner'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_testtube'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_icarus'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_skydiver'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_daedalus'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['digicert_ct1'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['izenpe_com_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['izenpe_eus_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_vega'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['wosign_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['wosign_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['cnnic_ctserver'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['gdca_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['startssl_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['certly_log'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['venafi_api_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_deneb'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['nordu_ct_plausible'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_dodo'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_mammoth'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['gdca_ctlog'].message_type = _CTSERVERSTATUS
_ROOTSTORESTATUS.fields_by_name['type'].enum_type = _CERTIFICATETYPE
_CERTIFICATEVALIDATION.fields_by_name['nss'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['microsoft'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['apple'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['java'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['android'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['google_ct_primary'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['google_ct_testtube'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['google_ct_submariner'].message_type = _ROOTSTORESTATUS
_CERTIFICATE.fields_by_name['source'].enum_type = _CERTIFICATESOURCE
_CERTIFICATE.fields_by_name['ct'].message_type = _CTSTATUS
_CERTIFICATE.fields_by_name['nss_audit'].message_type = _MOZILLASALESFORCESTATUS
_CERTIFICATE.fields_by_name['validation'].message_type = _CERTIFICATEVALIDATION
_CRYPTOGRAPHICKEY.fields_by_name['type'].enum_type = _CRYPTOGRAPHICKEY_KEYTYPE
_CRYPTOGRAPHICKEY.fields_by_name['rsa'].message_type = _RSACRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.fields_by_name['dsa'].message_type = _DSACRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.fields_by_name['ecc'].message_type = _ECCCRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY_KEYTYPE.containing_type = _CRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['rsa'])
_CRYPTOGRAPHICKEY.fields_by_name['rsa'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['dsa'])
_CRYPTOGRAPHICKEY.fields_by_name['dsa'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['ecc'])
_CRYPTOGRAPHICKEY.fields_by_name['ecc'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_ANONYMOUSRECORD.fields_by_name['userdata'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_ANONYMOUSRECORD.fields_by_name['certificate'].message_type = _CERTIFICATE
_ANONYMOUSRECORD.fields_by_name['key'].message_type = _CRYPTOGRAPHICKEY
_ANONYMOUSRECORD.fields_by_name['as'].message_type = zsearch__definitions_dot_common__pb2._ASATOM
_ANONYMOUSRECORD.fields_by_name['metadata'].message_type = zsearch__definitions_dot_common__pb2._METADATUM
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['data'])
_ANONYMOUSRECORD.fields_by_name['data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['raw_data'])
_ANONYMOUSRECORD.fields_by_name['raw_data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['certificate'])
_ANONYMOUSRECORD.fields_by_name['certificate'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['key'])
_ANONYMOUSRECORD.fields_by_name['key'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['as'])
_ANONYMOUSRECORD.fields_by_name['as'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_EXTERNALCERTIFICATE.fields_by_name['source'].enum_type = _CERTIFICATESOURCE
_EXTERNALCERTIFICATE.fields_by_name['anonymous_record'].message_type = _ANONYMOUSRECORD
_EXTERNALCERTIFICATE.fields_by_name['ct_server'].enum_type = _CTSERVER
_EXTERNALCERTIFICATE.fields_by_name['ct_status'].message_type = _CTSERVERSTATUS
_EXTERNALCERTIFICATE.fields_by_name['nss_status'].message_type = _MOZILLASALESFORCESTATUS
_SCT.fields_by_name['server'].enum_type = _CTSERVER
_SCT.fields_by_name['status'].message_type = _CTSERVERSTATUS
_ANONYMOUSDELTA.fields_by_name['delta_type'].enum_type = _ANONYMOUSDELTA_DELTATYPE
_ANONYMOUSDELTA.fields_by_name['delta_scope'].enum_type = _ANONYMOUSDELTA_DELTASCOPE
_ANONYMOUSDELTA.fields_by_name['record'].message_type = _ANONYMOUSRECORD
_ANONYMOUSDELTA_DELTATYPE.containing_type = _ANONYMOUSDELTA
_ANONYMOUSDELTA_DELTASCOPE.containing_type = _ANONYMOUSDELTA
DESCRIPTOR.message_types_by_name['CTServerStatus'] = _CTSERVERSTATUS
DESCRIPTOR.message_types_by_name['CTStatus'] = _CTSTATUS
DESCRIPTOR.message_types_by_name['RootStoreStatus'] = _ROOTSTORESTATUS
DESCRIPTOR.message_types_by_name['CertificateValidation'] = _CERTIFICATEVALIDATION
DESCRIPTOR.message_types_by_name['MozillaSalesForceStatus'] = _MOZILLASALESFORCESTATUS
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['RSACryptographicKey'] = _RSACRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['DSACryptographicKey'] = _DSACRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['ECCCryptographicKey'] = _ECCCRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['CryptographicKey'] = _CRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['AnonymousRecord'] = _ANONYMOUSRECORD
DESCRIPTOR.message_types_by_name['ExternalCertificate'] = _EXTERNALCERTIFICATE
DESCRIPTOR.message_types_by_name['SCT'] = _SCT
DESCRIPTOR.message_types_by_name['AnonymousDelta'] = _ANONYMOUSDELTA
DESCRIPTOR.enum_types_by_name['CTPushStatus'] = _CTPUSHSTATUS
DESCRIPTOR.enum_types_by_name['CertificateType'] = _CERTIFICATETYPE
DESCRIPTOR.enum_types_by_name['CertificateSource'] = _CERTIFICATESOURCE
DESCRIPTOR.enum_types_by_name['CTServer'] = _CTSERVER

CTServerStatus = _reflection.GeneratedProtocolMessageType('CTServerStatus', (_message.Message,), dict(
  DESCRIPTOR = _CTSERVERSTATUS,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CTServerStatus)
  ))
_sym_db.RegisterMessage(CTServerStatus)

CTStatus = _reflection.GeneratedProtocolMessageType('CTStatus', (_message.Message,), dict(
  DESCRIPTOR = _CTSTATUS,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CTStatus)
  ))
_sym_db.RegisterMessage(CTStatus)

RootStoreStatus = _reflection.GeneratedProtocolMessageType('RootStoreStatus', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTORESTATUS,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreStatus)
  ))
_sym_db.RegisterMessage(RootStoreStatus)

CertificateValidation = _reflection.GeneratedProtocolMessageType('CertificateValidation', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEVALIDATION,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateValidation)
  ))
_sym_db.RegisterMessage(CertificateValidation)

MozillaSalesForceStatus = _reflection.GeneratedProtocolMessageType('MozillaSalesForceStatus', (_message.Message,), dict(
  DESCRIPTOR = _MOZILLASALESFORCESTATUS,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.MozillaSalesForceStatus)
  ))
_sym_db.RegisterMessage(MozillaSalesForceStatus)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATE,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Certificate)
  ))
_sym_db.RegisterMessage(Certificate)

RSACryptographicKey = _reflection.GeneratedProtocolMessageType('RSACryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _RSACRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RSACryptographicKey)
  ))
_sym_db.RegisterMessage(RSACryptographicKey)

DSACryptographicKey = _reflection.GeneratedProtocolMessageType('DSACryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _DSACRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.DSACryptographicKey)
  ))
_sym_db.RegisterMessage(DSACryptographicKey)

ECCCryptographicKey = _reflection.GeneratedProtocolMessageType('ECCCryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _ECCCRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ECCCryptographicKey)
  ))
_sym_db.RegisterMessage(ECCCryptographicKey)

CryptographicKey = _reflection.GeneratedProtocolMessageType('CryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _CRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CryptographicKey)
  ))
_sym_db.RegisterMessage(CryptographicKey)

AnonymousRecord = _reflection.GeneratedProtocolMessageType('AnonymousRecord', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSRECORD,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousRecord)
  ))
_sym_db.RegisterMessage(AnonymousRecord)

ExternalCertificate = _reflection.GeneratedProtocolMessageType('ExternalCertificate', (_message.Message,), dict(
  DESCRIPTOR = _EXTERNALCERTIFICATE,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ExternalCertificate)
  ))
_sym_db.RegisterMessage(ExternalCertificate)

SCT = _reflection.GeneratedProtocolMessageType('SCT', (_message.Message,), dict(
  DESCRIPTOR = _SCT,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.SCT)
  ))
_sym_db.RegisterMessage(SCT)

AnonymousDelta = _reflection.GeneratedProtocolMessageType('AnonymousDelta', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSDELTA,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousDelta)
  ))
_sym_db.RegisterMessage(AnonymousDelta)


_CERTIFICATE.fields_by_name['in_nss'].has_options = True
_CERTIFICATE.fields_by_name['in_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['in_apple'].has_options = True
_CERTIFICATE.fields_by_name['in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['validation_timestamp'].has_options = True
_CERTIFICATE.fields_by_name['validation_timestamp']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['valid_nss'].has_options = True
_CERTIFICATE.fields_by_name['valid_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['was_valid_nss'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['was_valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['was_valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['was_in_nss'].has_options = True
_CERTIFICATE.fields_by_name['was_in_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['was_in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['was_in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['was_in_apple'].has_options = True
_CERTIFICATE.fields_by_name['was_in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['current_valid_nss'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['current_valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['current_valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['current_in_nss'].has_options = True
_CERTIFICATE.fields_by_name['current_in_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['current_in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['current_in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_CERTIFICATE.fields_by_name['current_in_apple'].has_options = True
_CERTIFICATE.fields_by_name['current_in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
_ANONYMOUSRECORD.fields_by_name['exported'].has_options = True
_ANONYMOUSRECORD.fields_by_name['exported']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\030\001')
# @@protoc_insertion_point(module_scope)
